@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1996 Open Market, Inc.
  *
- * See the file "LICENSE.TERMS" for information on usage and redistribution
+ * See the file "LICENSE" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
  */
@@ -1454,13 +1454,14 @@ static void EmptyBuffProc(struct FCGX_Stream *stream, int doClose)
 static int ProcessManagementRecord(int type, FCGX_Stream *stream)
 {
     FCGX_Stream_Data *data = (FCGX_Stream_Data *)stream->data;
-    ParamsPtr paramsPtr = NewParams(3);
+    ParamsPtr paramsPtr;
     char **pPtr;
     char response[64]; /* 64 = 8 + 3*(1+1+14+1)* + padding */
     char *responseP = &response[FCGI_HEADER_LEN];
     char *name, value = '\0';
     int len, paddedLen;
     if(type == FCGI_GET_VALUES) {
+        paramsPtr = NewParams(3);
         ReadParams(paramsPtr, stream);
         if((FCGX_GetError(stream) != 0) || (data->contentLen != 0)) {
             FreeParams(&paramsPtr);
@@ -2015,8 +2016,8 @@ void FCGX_Finish_r(FCGX_Request *reqDataPtr)
         close |= FCGX_FClose(reqDataPtr->out);
         close |= FCGX_GetError(reqDataPtr->in);
 
-        /* discard any remaining data in input stream */
-        if (!close && !reqDataPtr->in->isClosed) {
+        /* discard any remaining data in input stream on persistent connections */
+        if (!close && !reqDataPtr->in->isClosed && reqDataPtr->keepConnection) {
             FCGX_Stream *stream = reqDataPtr->in;
 
             do {
