@@ -1,19 +1,13 @@
 /*
  * os_unix.c --
  *
- *      Description of file.
- *
- *
- *  Copyright (c) 1995 Open Market, Inc.
- *  All rights reserved.
- *
- *  This file contains proprietary and confidential information and
- *  remains the unpublished property of Open Market, Inc. Use,
- *  disclosure, or reproduction is prohibited except as permitted by
- *  express written license agreement with Open Market, Inc.
- *
  *  Bill Snapper
  *  snapper@openmarket.com
+ *
+ * Copyright (c) 1996 Open Market, Inc.
+ *
+ * See the file "LICENSE" for information on usage and redistribution
+ * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
 #ifndef lint
@@ -292,6 +286,12 @@ int OS_CreateLocalIpcFd(const char *bindPath, int backlog)
     short   port = 0;
     char    host[MAXPATHLEN];
 
+    if (strlen(bindPath) >= MAXPATHLEN) {
+	    fprintf(stderr,
+            "Listening socket path is longer than %d bytes -- exiting!\n",
+            MAXPATHLEN);
+	    exit(1);
+    }
     strcpy(host, bindPath);
     if((tp = strchr(host, ':')) != 0) {
 	*tp++ = 0;
@@ -395,6 +395,10 @@ int OS_FcgiConnect(char *bindPath)
     short   port = 0;
     int	    tcp = FALSE;
 
+    if (strlen(bindPath) >= MAXPATHLEN) {
+	    fprintf(stderr, "Listening socket path is too long\n");
+	    exit(1000);
+    }
     strcpy(host, bindPath);
     if((tp = strchr(host, ':')) != 0) {
 	*tp++ = 0;
